<?php
/**
* եǥ륤󥿥ե
*
* PHP version 5
*
* @package    interfaces
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

interface IFormModel extends IModel
{
	/*
	 *   ϥȥ
	 */
	public function getInputList();

	/*
	 *   եॢΥơ
	 */
	public function getFormAnnotation( String $type );

	/*
	 *   եॢΥơͤ
	 */
	public function getFormAnnotationValue( String $type );

	/*
	 *   ǥեȤΥץ󥯥饹
	 */
	public function getDefaultCaptionClass();

	/*
	 *   ǥեȤΥץ󥹥
	 */
	public function getDefaultCaptionStyle();

	/*
	 *   ǥեȤΥեɥ饹
	 */
	public function getDefaultFieldClass( String $field_type );

	/*
	 *   ǥեȤΥեɥ
	 */
	public function getDefaultFieldStyle( String $field_type );

	/*
	 *   ꥹȤθ
	 */
	public function getChoiceList( String $list_name );

}

return __FILE__;